@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; buffer-read-only: t -*-
 
-__version__ = "1.0.2"
+__version__ = "1.1.1"
 
 from ._version import *
 from .log import *
@@ -10,9 +10,9 @@ from .helpers import *
 # from . import cv # rh.cv.say_hello
 # from .cv import say_hello, hello_cv # rh.say_hello
 from .cv import *
-from .core import RobotAtHome
+from .core import *
 
-__all__=[]
+__all__ = []
 __all__.extend(_version.__all__)
 __all__.extend(log.__all__)
 __all__.extend(helpers.__all__)
