@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; buffer-read-only: t -*-
 
-from .reader import * 
+from .reader import *
+from .df import *
 
 __all__=[]
 __all__.extend(reader.__all__)
-
+__all__.extend(df.__all__)
